4.20. umbra.components.factory.scriptEditor.searchAndReplace — Umbra 1.0.4 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »

# 4.20. umbra.components.factory.scriptEditor.searchAndReplace

searchAndReplace.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `SearchAndReplace` class.

Others:

## 4.20.1. Module Attributes

`umbra.components.factory.scriptEditor.searchAndReplace.` `LOGGER`

`umbra.components.factory.scriptEditor.searchAndReplace.` `UI_FILE`

## 4.20.2. Classes

class `umbra.components.factory.scriptEditor.searchAndReplace.` `ValidationFilter`

  Bases: `PyQt4.QtCore.QObject`

  This class is a QObject subclass used as an event filter for the `SearchAndReplace` class.

  `eventFilter`(object, event)

    This method reimplements the QObject.eventFilter method.

    Parameters: | object – Object. ( QObject ) event – Event. ( QEvent )
    Returns: | Event filtered. ( Boolean )

class `umbra.components.factory.scriptEditor.searchAndReplace.` `SearchAndReplace`(parent, *args, **kwargs)

  Bases: `foundations.ui.common.QWidget`

  This class defines the default search and replace dialog used by the ScriptEditor Component.

  Parameters: | parent – Object parent. ( QObject ) *args – Arguments. ( * ) **kwargs – Keywords arguments. ( ** )

  `container`

    This method is the property for self.__container attribute.

    Returns: | self.__container. ( QObject )

  `searchPatternsModel`

    This method is the property for self.__searchPatternsModel attribute.

    Returns: | self.__searchPatternsModel. ( PatternsModel )

  `replaceWithPatternsModel`

    This method is the property for self.__replaceWithPatternsModel attribute.

    Returns: | self.__replaceWithPatternsModel. ( PatternsModel )

  `maximumStoredPatterns`

    This method is the property for self.__maximumStoredPatterns attribute.

    Returns: | self.__maximumStoredPatterns. ( Integer )

  `show`()

    This method reimplements the `QWidget.show()` method.

  `insertPattern`(pattern, model, index=0)

    This definition inserts given pattern into given Model.

    Parameters: | pattern – Pattern. ( String ) model – Model. ( PatternsModel ) index – Insertion indes. ( Integer )
    Returns: | Method success. ( Boolean )

  `search`()

    This method searchs current editor Widget for search pattern.

    Returns: | Method success. ( Boolean )

  `replace`()

    This method replaces current editor Widget current search pattern occurence with replacement pattern.

    Returns: | Method success. ( Boolean )

  `replaceAll`()

    This method replaces current editor Widget search pattern occurences with replacement pattern.

    Returns: | Method success. ( Boolean )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »